==> jc-1.4.0.tar.gz: soot/toolkits/scalar/BackwardFlowAnalysis.h <==
// public abstract class soot.toolkits.scalar.BackwardFlowAnalysis

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class 722d252e8e2e5e52 soot_toolkits_scalar_BackwardFlowAnalysis
// @dep_class d57b0cae040f1388 soot_toolkits_scalar_FlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_FlowAnalysis

#include "soot/toolkits/scalar/FlowAnalysis.h"

#ifndef _JC_soot_toolkits_scalar_BackwardFlowAnalysis_H_
#define _JC_soot_toolkits_scalar_BackwardFlowAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_refs	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_refs;
typedef struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_nonrefs	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$refs	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$refs;
typedef struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$nonrefs	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$nonrefs;
typedef struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$object	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$object;

typedef const struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$vmethods	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$vmethods;
typedef const struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$vtable	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$vtable;
typedef const struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$vtype	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_BackwardFlowAnalysis$method$_init$ac2601640312c3c2(_jc_env *, struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_toolkits_scalar_BackwardFlowAnalysis$method$doAnalysis$aa9bebddf0f94464(_jc_env *, struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$object *);
extern jboolean _jc_soot_toolkits_scalar_BackwardFlowAnalysis$method$isForward$48ad1d1fce741d09(_jc_env *, struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_BackwardFlowAnalysis$method_info$doAnalysis$aa9bebddf0f94464;
extern _jc_method _jc_soot_toolkits_scalar_BackwardFlowAnalysis$method_info$isForward$48ad1d1fce741d09;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$vmethods {
	void	(*doAnalysis$aa9bebddf0f94464)(_jc_env *, struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$object *);
	jboolean	(*isForward$48ad1d1fce741d09)(_jc_env *, struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods	soot_toolkits_scalar_FlowAnalysis;
	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$vmethods	soot_toolkits_scalar_BackwardFlowAnalysis;
};

// Vtype
struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$refs {
    _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_refs	soot_toolkits_scalar_BackwardFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_BackwardFlowAnalysis;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$object {
	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$vtype	*vtype;
	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_BackwardFlowAnalysis$vtype _jc_soot_toolkits_scalar_BackwardFlowAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_BackwardFlowAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_BackwardFlowAnalysis$class_object;

#endif	/* _JC_soot_toolkits_scalar_BackwardFlowAnalysis_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/BackwardFlowAnalysis.h <==
// public abstract class soot.toolkits.scalar.BackwardFlowAnalysis

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class 722d252e8e2e5e52 soot_toolkits_scalar_BackwardFlowAnalysis
// @dep_class d57b0cae040f1388 soot_toolkits_scalar_FlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_FlowAnalysis

#include "soot/toolkits/scalar/FlowAnalysis.h"

#ifndef _JC_soot_toolkits_scalar_BackwardFlowAnalysis_H_
#define _JC_soot_toolkits_scalar_BackwardFlowAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_refs	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_refs;
typedef struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_nonrefs	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$refs	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$refs;
typedef struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$nonrefs	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$nonrefs;
typedef struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$object	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$object;

typedef const struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$vmethods	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$vmethods;
typedef const struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$vtable	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$vtable;
typedef const struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$vtype	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_BackwardFlowAnalysis$method$_init$ac2601640312c3c2(_jc_env *, struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_toolkits_scalar_BackwardFlowAnalysis$method$doAnalysis$aa9bebddf0f94464(_jc_env *, struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_toolkits_scalar_BackwardFlowAnalysis$method$isForward$48ad1d1fce741d09(_jc_env *, struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_BackwardFlowAnalysis$method_info$doAnalysis$aa9bebddf0f94464;
extern _jc_method _jc_soot_toolkits_scalar_BackwardFlowAnalysis$method_info$isForward$48ad1d1fce741d09;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$vmethods {
	void	(*doAnalysis$aa9bebddf0f94464)(_jc_env *, struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$object *) _JC_JCNI_ATTR;
	jboolean	(*isForward$48ad1d1fce741d09)(_jc_env *, struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods	soot_toolkits_scalar_FlowAnalysis;
	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$vmethods	soot_toolkits_scalar_BackwardFlowAnalysis;
};

// Vtype
struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$refs {
    _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_refs	soot_toolkits_scalar_BackwardFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_BackwardFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_BackwardFlowAnalysis;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_BackwardFlowAnalysis$object {
	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$vtype	*vtype;
	_jc_soot_toolkits_scalar_BackwardFlowAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_BackwardFlowAnalysis$vtype _jc_soot_toolkits_scalar_BackwardFlowAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_BackwardFlowAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_BackwardFlowAnalysis$class_object;

#endif	/* _JC_soot_toolkits_scalar_BackwardFlowAnalysis_H_ */
